@@ -12,6 +12,7 @@ import os
 import copy
 import platform
 import subprocess
+import warnings
 # In py3, ConfigParser was renamed to the more-standard configparser.
 # But there's a py3 backport that installs "configparser" in py2, and I don't
 # want it because it has annoying deprecation warnings. So try the real py2
@@ -48,6 +49,7 @@ class parser_configuration_t(object):
             define_symbols=None,
             undefine_symbols=None,
             cflags="",
+            ccflags="",
             compiler=None,
             xml_generator=None,
             keep_xml=False,
@@ -72,6 +74,8 @@ class parser_configuration_t(object):
 
         self.__cflags = cflags
 
+        self.__ccflags = ccflags
+
         self.__compiler = compiler
 
         self.__xml_generator = xml_generator
@@ -196,12 +200,36 @@ class parser_configuration_t(object):
     def append_cflags(self, val):
         self.__cflags = self.__cflags + ' ' + val
 
+    @property
+    def ccflags(self):
+        """
+        additional cross-compatible flags to pass directly
+        to internal simulated compiler.
+        Castxml removes any definitions of its
+        pre-defined macros (e.g. -fopenmp). To propagate these down to the
+        compiler, these flags must also be passed here.
+        See `cc-opt` on castxml's documentation page:
+        https://github.com/CastXML/CastXML/blob/master/doc/manual/castxml.1.rst
+        """
+        return self.__ccflags
+
+    @ccflags.setter
+    def ccflags(self, val):
+        self.__ccflags = val
+
+    def append_ccflags(self, val):
+        self.__ccflags = self.__ccflags + ' ' + val
+
     def __ensure_dir_exists(self, dir_path, meaning):
         if os.path.isdir(dir_path):
             return
         if os.path.exists(self.working_directory):
-            raise RuntimeError(
-                '%s("%s") does not exist!' % (meaning, dir_path))
+            msg = '%s("%s") does not exist.' % (meaning, dir_path)
+            if meaning == 'include directory':
+                # Warn instead of failing.
+                warnings.warn(msg, RuntimeWarning)
+            else:
+                raise RuntimeError(msg)
         else:
             raise RuntimeError(
                 '%s("%s") should be "directory", not a file.' %
@@ -240,6 +268,7 @@ class xml_generator_configuration_t(parser_configuration_t):
             start_with_declarations=None,
             ignore_gccxml_output=False,
             cflags="",
+            ccflags="",
             compiler=None,
             xml_generator=None,
             keep_xml=False,
@@ -254,6 +283,7 @@ class xml_generator_configuration_t(parser_configuration_t):
             define_symbols=define_symbols,
             undefine_symbols=undefine_symbols,
             cflags=cflags,
+            ccflags=ccflags,
             compiler=compiler,
             xml_generator=xml_generator,
             keep_xml=keep_xml,
@@ -393,6 +423,8 @@ def load_xml_generator_configuration(configuration, **defaults):
             cfg.keep_xml = value
         elif name == 'cflags':
             cfg.cflags = value
+        elif name == 'ccflags':
+            cfg.ccflags = value
         elif name == 'flags':
             cfg.flags = value
         elif name == 'compiler_path':
@@ -414,7 +446,7 @@ def create_compiler_path(xml_generator, compiler_path):
     """
     Try to guess a path for the compiler.
 
-    If you want ot use a specific compiler, please provide the compiler
+    If you want to use a specific compiler, please provide the compiler
     path manually, as the guess may not be what you are expecting.
     Providing the path can be done by passing it as an argument (compiler_path)
     to the xml_generator_configuration_t() or by defining it in your pygccxml
@@ -425,45 +457,17 @@ def create_compiler_path(xml_generator, compiler_path):
     if xml_generator == 'castxml' and compiler_path is None:
         if platform.system() == 'Windows':
             # Look for msvc
-            p = subprocess.Popen(
-                ['where', 'cl'],
-                stdout=subprocess.PIPE,
-                stderr=subprocess.PIPE)
-            compiler_path = p.stdout.read().decode("utf-8").rstrip()
-            p.wait()
-            p.stdout.close()
-            p.stderr.close()
+            compiler_path = __get_first_compiler_in_path('where', 'cl')
             # No msvc found; look for mingw
             if compiler_path == '':
-                p = subprocess.Popen(
-                    ['where', 'mingw'],
-                    stdout=subprocess.PIPE,
-                    stderr=subprocess.PIPE)
-                compiler_path = p.stdout.read().decode("utf-8").rstrip()
-                p.wait()
-                p.stdout.close()
-                p.stderr.close()
+                compiler_path = __get_first_compiler_in_path('where', 'mingw')
         else:
             # OS X or Linux
             # Look for clang first, then gcc
-            p = subprocess.Popen(
-                ['which', 'clang++'],
-                stdout=subprocess.PIPE,
-                stderr=subprocess.PIPE)
-            compiler_path = p.stdout.read().decode("utf-8").rstrip()
-            p.wait()
-            p.stdout.close()
-            p.stderr.close()
+            compiler_path = __get_first_compiler_in_path('which', 'clang++')
             # No clang found; use gcc
             if compiler_path == '':
-                p = subprocess.Popen(
-                    ['which', 'c++'],
-                    stdout=subprocess.PIPE,
-                    stderr=subprocess.PIPE)
-                compiler_path = p.stdout.read().decode("utf-8").rstrip()
-                p.wait()
-                p.stdout.close()
-                p.stderr.close()
+                compiler_path = __get_first_compiler_in_path('which', 'c++')
 
         if compiler_path == "":
             compiler_path = None
@@ -471,5 +475,17 @@ def create_compiler_path(xml_generator, compiler_path):
     return compiler_path
 
 
+def __get_first_compiler_in_path(command, compiler_name):
+    p = subprocess.Popen(
+        [command, compiler_name],
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE)
+    path = p.stdout.read().decode("utf-8").rstrip().split("\r\n")[0].rstrip()
+    p.wait()
+    p.stdout.close()
+    p.stderr.close()
+    return path
+
+
 if __name__ == '__main__':
     print(load_xml_generator_configuration('xml_generator.cfg').__dict__)
