@@ -23,7 +23,6 @@ sys.path.insert(1, os.path.join(os.curdir, '..'))
 # in site-packages. Insert the directory's path.
 sys.path.insert(1, "../pygccxml")
 
-from pygccxml import declarations  # nopep8
 from pygccxml import parser  # nopep8
 from pygccxml import utils  # nopep8
 
@@ -38,8 +37,6 @@ utils.loggers.set_level(logging.CRITICAL)
 # Find out the c++ parser (gccxml or castxml)
 generator_path, generator_name = utils.find_xml_generator()
 
-declarations.class_t.USE_DEMANGLED_AS_NAME = True
-
 
 class cxx_parsers_cfg(object):
     config = parser.load_xml_generator_configuration(
