@@ -1,7 +1,7 @@
-// Copyright 2004-2008 Roman Yakovenko.
-// Distributed under the Boost Software License, Version 1.0. (See
-// accompanying file LICENSE_1_0.txt or copy at
-// http://www.boost.org/LICENSE_1_0.txt)
+// Copyright 2014-2017 Insight Software Consortium.
+// Copyright 2004-2009 Roman Yakovenko.
+// Distributed under the Boost Software License, Version 1.0.
+// See http://www.boost.org/LICENSE_1_0.txt
 
 #ifndef __unnamed_classes_hpp__
 #define __unnamed_classes_hpp__
@@ -24,8 +24,8 @@ struct S1{
 			};
 			unsigned int raw;
 		} flags;
-        
-		union FileAttribs{
+
+		union {
 			struct{
 				unsigned int isReadOnly : 1;
 				unsigned int isHidden : 1;
@@ -45,6 +45,16 @@ struct S1{
 			unsigned int raw;
 		} fileattribs;		// in GetFileAttributes() format
 	} header;
+
+	struct S3{
+		union
+		{
+			char anon_mem_c;
+			int anon_mem_i;
+		};
+		long s3_mem;
+		S2 s2;
+	};
 };
 
 } // namespace
