@@ -49,9 +49,10 @@ class Test(parser_test_case.parser_test_case_t):
             if nbr == 21:
                 # We are using llvm 3.9, see bug #32. Make sure the 4 names
                 # are still there
-                ll = ["isa", "flags", "str", "length"]
-                for l in ll:
-                    self.assertTrue(l in [mbr.name for mbr in public_members])
+                names = ["isa", "flags", "str", "length"]
+                for name in names:
+                    self.assertTrue(
+                        names in [mbr.name for mbr in public_members])
         else:
             self.assertTrue(17 == len(public_members))
 
@@ -64,16 +65,8 @@ class Test(parser_test_case.parser_test_case_t):
         found = declarations.matcher.find(
             criteria1 | criteria2,
             self.global_ns)
-
-        if self.xml_generator_from_xml_file.is_castxml:
-            found = [d for d in found if not d.is_artificial]
-            self.assertTrue(len(found) != 35)
-        elif self.xml_generator_from_xml_file.is_gccxml_09 or \
-                self.xml_generator_from_xml_file.is_gccxml_09_buggy:
-            found = [d for d in found if not d.is_artificial]
-            self.assertTrue(15 <= len(found) <= 21)
-        else:
-            self.assertTrue(19 <= len(found) <= 25)
+        found = [d for d in found if not d.is_artificial]
+        self.assertTrue(len(found) != 35)
 
     def test_and_matcher(self):
         criteria1 = declarations.regex_matcher_t(
